@@ -76,7 +76,8 @@ class Elasticsearchlib:
         _es = Elasticsearch(hosts=[{'host': host, 'port': port}],
                             http_auth=('easier', 'easier-123.'),
                             scheme="https",
-                            ssl_context=ssl_context)
+                            ssl_context=ssl_context,
+                            verify_certs=False)
         self.request_retries = request_retries
         self.total_retries = total_retries
         self.current_total_retries = self.total_retries
